@@ -58,6 +58,9 @@ class FeatureFlag(Enum):
     COMPLIANCE = "compliance"
     ADVANCED_SECURITY = "advanced_security"
 
+    # Testing and Development features
+    TDD_MODE = "tdd_mode"  # Test-driven development infrastructure
+
 
 @dataclass
 class DatabaseConfiguration:
