@@ -1,12 +1,36 @@
-"""DataFlow Production Engine."""
+"""DataFlow Production Engine - DEPRECATED.
+
+.. deprecated:: 0.7.0
+   This module has been moved to tests.fixtures.engine_testing_mocks.
+   Import from there instead:
+
+   from tests.fixtures.engine_testing_mocks import (
+       MockConnectionPool,
+       MockConnection,
+       MockCursor,
+       DataFlowProductionEngine
+   )
+
+This module will be removed in v0.8.0.
+"""
 
 import asyncio
+import warnings
 from dataclasses import dataclass
 from datetime import datetime
 from typing import Any, Dict, List, Optional
 
 from .config import DatabaseConfig, DataFlowConfig, Environment
 
+# Issue deprecation warning when this module is imported
+warnings.warn(
+    "The module dataflow.core.engine_production is deprecated and has been moved to "
+    "tests.fixtures.engine_testing_mocks. Please update your imports. "
+    "This module will be removed in v0.8.0.",
+    DeprecationWarning,
+    stacklevel=2,
+)
+
 
 class MockConnectionPool:
     """Mock connection pool for testing purposes."""
