@@ -22,11 +22,11 @@ import pytest
 # Add DataFlow to path
 sys.path.insert(0, str(Path(__file__).parent.parent / "src"))
 
+from dataflow import DataFlow
+
 from kailash.runtime import AsyncLocalRuntime
 from kailash.workflow.builder import WorkflowBuilder
 
-from dataflow import DataFlow
-
 
 class TestBugFix1_BulkOperationsStringLiteral:
     """Regression tests for BUG #1: Bulk Operations String Literal Bug"""
@@ -176,8 +176,8 @@ class TestBugFix2_UpdateNodeDatetimeConversion:
             {
                 "filter": {"name": "Conference"},
                 "fields": {
-                    "event_date": "2024-07-20T16:00:00"  # ISO string, not datetime object
-                },
+                    "event_date": "2024-07-20T16:00:00"
+                },  # ISO string, not datetime object
             },
         )
 
@@ -235,8 +235,8 @@ class TestBugFix2_UpdateNodeDatetimeConversion:
             {
                 "filter": {"message": "Test"},
                 "fields": {
-                    "timestamp": "2024-09-15T12:30:45.123456"  # With microseconds
-                },
+                    "timestamp": "2024-09-15T12:30:45.123456"
+                },  # With microseconds
             },
         )
 
@@ -264,8 +264,8 @@ class TestBugFix2_UpdateNodeDatetimeConversion:
             {
                 "filter": {"description": "Write docs"},
                 "fields": {
-                    "due_date": "2024-10-01T18:00:00+05:30"  # With timezone offset
-                },
+                    "due_date": "2024-10-01T18:00:00+05:30"
+                },  # With timezone offset
             },
         )
 
